# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/32_embs.ipynb.

# %% auto 0
__all__ = ['X', 'X_', 'X_MAGIC', 'X_PCA', 'X_PCA_HVG', 'X_PHATE', 'X_PHATE_HVG']

# %% ../nbs/32_embs.ipynb 4
from nchr import S_
from .mthd import MAGIC, PCA, PHATE
from .biol import X, X_, HVG

# %% ../nbs/32_embs.ipynb 5
X = 'X'
X_ = f'{X}{S_}'

# %% ../nbs/32_embs.ipynb 7
# Layer storing MAGIC embedding in adata.obsm
X_MAGIC = f'{X_}{MAGIC}'

# Layer storing PCA embedding in adata.obsm
X_PCA = f'{X_}{PCA}'

# Layer storing PCA embedding just on HVGs in adata.obsm
X_PCA_HVG = f'{X_}{PCA}_{HVG}'

# Layer storing PHATE embedding just in adata.obsm
X_PHATE = f'{X_}{PHATE}'

# Layer storing PHATE embedding just on HVGs in adata.obsm
X_PHATE_HVG = f'{X_}{PHATE}_{HVG}'
