# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/60_narr.ipynb.

# %% auto 0
__all__ = ['NDIM', 'DIMS', 'DTYPE', 'SHAPE', 'TOARRAY', 'TODENSE', 'TOLIST']

# %% ../nbs/60_narr.ipynb 5
NDIM = 'ndim'
DIMS = 'dims'

DTYPE = 'dtype'
SHAPE = 'shape'

TOARRAY = 'toarray'
TODENSE = 'todense'
TOLIST = 'tolist'
