# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/31_mthd.ipynb.

# %% auto 0
__all__ = ['DPT', 'PCA', 'UMAP', 'TSNE', 'PHATE', 'MAGIC', 'PSEUDOTIME', 'DPT_PSEUDOTIME']

# %% ../nbs/31_mthd.ipynb 4
from nchr import S_
from .exps import TIME

# %% ../nbs/31_mthd.ipynb 6
DPT   = 'dpt'
PCA   = 'pca'
UMAP  = 'umap'
TSNE  = 'tsne'
PHATE = 'phate'
MAGIC = 'magic'

# %% ../nbs/31_mthd.ipynb 7
PSEUDOTIME = f'pseudo{TIME}'
DPT_PSEUDOTIME = f'{DPT}{S_}{PSEUDOTIME}'
