# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/61_tens.ipynb.

# %% auto 0
__all__ = ['DETACH', 'DEVICE', 'CUDA', 'MPS', 'CPU', 'IPU', 'XPU', 'TPU', 'MKLDNN', 'OPENGL', 'OPENCL', 'VULKAN', 'IDEEP', 'HIP',
           'VE', 'FPGA', 'ORT', 'XLA', 'LAZY', 'META', 'HPU', 'PRIVATEUSEONE', 'CLONE', 'NUMPY']

# %% ../nbs/61_tens.ipynb 5
DETACH = 'detach'
DEVICE = 'device'

# %% ../nbs/61_tens.ipynb 7
CUDA = 'cuda'
MPS = 'mps'
CPU = 'cpu'
IPU = 'ipu'
XPU = 'xpu'
TPU = 'tpu'
MKLDNN = 'mkldnn'
OPENGL = 'opengl'
OPENCL = 'opencl'
VULKAN = 'vulkan'
IDEEP = 'ideep'
HIP = 'hip'
VE = 've'
FPGA = 'fpga'
ORT = 'ort'
XLA = 'xla'
LAZY = 'lazy'
META = 'meta'
HPU = 'hpu'
PRIVATEUSEONE = 'privateuseone'

# %% ../nbs/61_tens.ipynb 9
CLONE = 'clone'
DETACH = 'detach'
NUMPY = 'numpy'
