# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/30_exps.ipynb.

# %% auto 0
__all__ = ['ID', 'ITEM', 'NAME', 'SEED', 'BATCH', 'TOTAL', 'PCT', 'PERCENT', 'DAY', 'TIME', 'TIMEPOINT', 'TIMEPOINTS', 'COUNT',
           'NORM', 'NORMALIZED', 'CON', 'CONDITION', 'CONDITIONS', 'SAMPLE', 'SAMPLES', 'TREATMENT', 'TREATMENTS',
           'SENS', 'SENSITIVITY', 'SENSITIVITIES']

# %% ../nbs/30_exps.ipynb 4
from nchr import S_

# %% ../nbs/30_exps.ipynb 6
ID = 'id'

# %% ../nbs/30_exps.ipynb 7
ITEM = 'item'
NAME = 'name'
SEED = 'seed'

# %% ../nbs/30_exps.ipynb 8
BATCH = 'batch'
TOTAL = 'total'

# %% ../nbs/30_exps.ipynb 9
PCT = 'pct'
PERCENT = 'percent'

# %% ../nbs/30_exps.ipynb 10
DAY = 'day'
TIME = 'time'
TIMEPOINT = f'{TIME}point'
TIMEPOINTS = f'{TIMEPOINT}s'

# %% ../nbs/30_exps.ipynb 11
COUNT = 'count'

# %% ../nbs/30_exps.ipynb 12
NORM = 'norm'
NORMALIZED = f'{NORM}alized'

# %% ../nbs/30_exps.ipynb 13
CON = 'con'
CONDITION = f'{CON}dition'
CONDITIONS = f'{CONDITION}s'

# %% ../nbs/30_exps.ipynb 14
SAMPLE = 'sample'
SAMPLES = f'{SAMPLE}s'

# %% ../nbs/30_exps.ipynb 15
TREATMENT = f'treatment'
TREATMENTS = f'{TREATMENT}s'

# %% ../nbs/30_exps.ipynb 16
SENS = 'sens'
SENSITIVITY = f'{SENS}itivity'
SENSITIVITIES = f'{SENS}itivities'
