# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_args.ipynb.

# %% auto 0
__all__ = ['N', 'IDX', 'SEP', 'FMT', 'ATTR', 'DESC', 'FUNC', 'KIND', 'TYPE', 'REPR', 'OPTS', 'SHOW', 'PREF', 'LINK', 'HUSH',
           'QUIET', 'RAISE', 'FAILQ', 'SPEC', 'SPECS', 'DEBUG', 'PRINT', 'VALUE', 'CUTOFF', 'MIXINS', 'UNIQUE',
           'HIDDEN', 'IGNORE', 'DEFAULT', 'INPLACE', 'VERBOSE', 'OPTIONAL', 'REQUIRED', 'ASMEMBER', 'ABRV', 'SYMB',
           'CONS', 'FMTFUNC', 'MOD', 'PKG', 'BEG', 'END', 'POS', 'NEG', 'LEN', 'DIG', 'BRV', 'FIX', 'OVERWRITE',
           'OVERWRITABLE']

# %% ../nbs/02_args.ipynb 5
N = 'n'

# %% ../nbs/02_args.ipynb 6
IDX = 'idx'
SEP = 'sep'
FMT = 'fmt'

# %% ../nbs/02_args.ipynb 7
ATTR = 'attr'
DESC = 'desc'
FUNC = 'func'
KIND = 'kind'
TYPE = 'type'
REPR = 'repr'
OPTS = 'opts'
SHOW = 'show'
PREF = 'pref'

# %% ../nbs/02_args.ipynb 8
LINK = 'link'

# %% ../nbs/02_args.ipynb 9
HUSH = 'hush'
QUIET = 'quiet'
RAISE = 'raise'
FAILQ = 'failq'

# %% ../nbs/02_args.ipynb 10
SPEC = 'spec'
SPECS = f'{SPEC}s'

# %% ../nbs/02_args.ipynb 11
DEBUG = 'debug'
PRINT = 'print'
VALUE = 'value'

# %% ../nbs/02_args.ipynb 12
CUTOFF = 'cutoff'
MIXINS = 'mixins'
UNIQUE = 'unique'

# %% ../nbs/02_args.ipynb 13
HIDDEN = 'hidden'
IGNORE = 'ignore'

# %% ../nbs/02_args.ipynb 14
DEFAULT = 'default'
INPLACE = 'inplace'
VERBOSE = 'verbose'

# %% ../nbs/02_args.ipynb 15
OPTIONAL = 'optional'
REQUIRED = 'required'

# %% ../nbs/02_args.ipynb 17
ASMEMBER = 'asmember'

# %% ../nbs/02_args.ipynb 19
ABRV = 'abrv'
SYMB = 'symb'

CONS = 'cons'

# %% ../nbs/02_args.ipynb 20
FMTFUNC = f'{FMT}{FUNC}'

# %% ../nbs/02_args.ipynb 23
MOD = 'mod'
PKG = 'pkg'

# %% ../nbs/02_args.ipynb 25
BEG = 'beg' # beginning
END = 'end' # end / ending

POS = 'pos' # positive
NEG = 'neg' # nevative

LEN = 'len' # length
DIG = 'dig' # digits

BRV = 'brv' # brv / abbreviation
FIX = 'fix' # prefix / suffix

# %% ../nbs/02_args.ipynb 27
OVERWRITE = 'overwrite'
OVERWRITABLE = 'overwritable'
