# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/101_hrdw.ipynb.

# %% auto 0
__all__ = ['GPFS', 'GIBBS', 'IZALITH', 'MCCLEARY']

# %% ../nbs/101_hrdw.ipynb 6
GPFS = 'gpfs'
GIBBS = 'gibbs'
IZALITH = 'izalith'
MCCLEARY = 'mccleary'
